ActionRecord class

A record of a single state mutation.

Constructors

ActionRecord({required ReactonRef reactonRef, required dynamic oldValue, required dynamic newValue, required DateTime timestamp, StackTrace? stackTrace})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
newValue → dynamic
The new value.
final
oldValue → dynamic
The previous value.
final
reactonRef ReactonRef
The reacton that was modified.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Stack trace at the point of mutation (for debugging).
final
timestamp DateTime
When the action occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited