MaxValue<T extends Comparable<T>> class

Max-value conflict resolution (GCounter pattern).

Always picks the numerically greater value. Suitable for monotonically increasing counters where each node increments independently.

T must implement Comparable.

Inheritance

Constructors

MaxValue()
Creates a MaxValue strategy.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(T localValue, T remoteValue, VectorClock localClock, VectorClock remoteClock, int localTimestamp, int remoteTimestamp) → T
Resolves a conflict between a local and remote value.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited