TransitionContext<S> class

Context available during state machine transitions.

Constructors

TransitionContext(S currentState, {ReactonReader? read})
const

Properties

currentState → S
final
hashCode int
The hash code for this object.
no setterinherited
read ReactonReader?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited